
# Slot: strand


The strand on which a feature is located. Has a value of '+' (sense strand or forward strand) or '-' (anti-sense strand or reverse strand).

URI: [biolink:strand](https://w3id.org/biolink/vocab/strand)


## Domain and Range

[GenomicSequenceLocalization](GenomicSequenceLocalization.md) &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents

 *  is_a: [sequence localization attribute](sequence_localization_attribute.md)

## Children


## Used by

 * [GenomicSequenceLocalization](GenomicSequenceLocalization.md)
